#
# spec file for package libesedb
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname	libesedb1
Name:           libesedb
Version:        20240420
Release:        1.2
Summary:        Library and tools to access the ESE Database File (EDB) format
License:        GFDL-1.1-or-later AND LGPL-3.0-or-later AND GFDL-1.3-or-later
Group:          Productivity/File utilities
URL:            https://github.com/libyal/libesedb
Source:         https://github.com/libyal/libesedb/releases/download/%version/libesedb-experimental-%version.tar.gz
Source2:        https://github.com/libyal/libesedb/releases/download/%version/libesedb-experimental-%version.tar.gz.asc
Source3:        %name.keyring
Source10:       Exchange.pdf
Source11:       Extensible_Storage_Engine_ESE_Database_File_EDB_format.pdf
Source12:       Forensic_analysis_of_the_Windows_Search_database.pdf
Source13:       Windows_Search.pdf
Source14:       libesedb-libfdata.pdf
BuildRequires:  %python_module devel
BuildRequires:  %python_module setuptools
BuildRequires:  c_compiler
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(libbfio) >= 20240414
BuildRequires:  pkgconfig(libcdata) >= 20240414
BuildRequires:  pkgconfig(libcerror) >= 20240413
BuildRequires:  pkgconfig(libcfile) >= 20240414
BuildRequires:  pkgconfig(libclocale) >= 20240414
BuildRequires:  pkgconfig(libcnotify) >= 20240414
BuildRequires:  pkgconfig(libcpath) >= 20240414
BuildRequires:  pkgconfig(libcsplit) >= 20240414
BuildRequires:  pkgconfig(libcthreads) >= 20240413
BuildRequires:  pkgconfig(libfcache) >= 20240414
BuildRequires:  pkgconfig(libfdata) >= 20240415
BuildRequires:  pkgconfig(libfdatetime) >= 20240415
BuildRequires:  pkgconfig(libfguid) >= 20240415
BuildRequires:  pkgconfig(libfmapi) >= 20240415
BuildRequires:  pkgconfig(libfvalue) >= 20240415
BuildRequires:  pkgconfig(libfwnt) >= 20240415
BuildRequires:  pkgconfig(libmapidb) >= 20240420
BuildRequires:  pkgconfig(libuna) >= 20240414
%python_subpackages
# Various notes: https://en.opensuse.org/libyal

%description
Library and tools to access the Extensible Storage Engine (ESE) Database File
(EDB) format. ESEDB is used in may different applications like Windows Search,
Windows Mail, Exchange, Active Directory, etc.

%package -n %lname
Summary:        Library to access the EDB format
License:        LGPL-3.0-or-later
Group:          System/Libraries

%description -n %lname
Library to access the Extensible Storage Engine (ESE) Database File (EDB)
format. ESEDB is used in may different applications like Windows Search,
Windows Mail, Exchange, Active Directory, etc.

%package tools
Summary:        Tools to access the EDB format
License:        LGPL-3.0-or-later
Group:          Productivity/File utilities

%description tools
Tools to access the Extensible Storage Engine (ESE) Database File (EDB) format.
ESEDB is used in may different applications like Windows Search, Windows Mail,
Exchange, Active Directory, etc.

%package devel
Summary:        Development files for libesedb, a EDB file format library
License:        GFDL-1.1-or-later AND LGPL-3.0-or-later AND GFDL-1.3-or-later
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       libbfio-devel

%description devel
libesedb is a library to access EDB files. ESEDB is used in many different
applications like Windows Search, Windows Mail, Exchange, Active Directory, etc.

This subpackage contains libraries and header files for developing
applications that want to make use of libesedb.

%prep
%autosetup -p1
cp "%_sourcedir"/*.pdf .

%build
%{python_expand #
echo "V_%version { global: *; };" >v.sym
%configure --disable-static --enable-wide-character-type \
	--enable-python PYTHON_VERSION="%{$python_bin_suffix}" \
	LDFLAGS="-Wl,--version-script=$PWD/v.sym"
grep ' '' ''local' config.log && exit 1
%make_build
%make_install DESTDIR="%_builddir/rt"
%make_build clean
}

%install
mv %_builddir/rt/* %buildroot/
find %buildroot -type f -name "*.la" -delete -print

%ldconfig_scriptlets -n %lname

%files -n %lname
%license COPYING*
%_libdir/libesedb.so.*

%files -n %name-tools
%license COPYING*
%_bindir/esedb*
%_mandir/man1/esedb*.1*

%files -n %name-devel
%license COPYING*
%doc Exchange.pdf
%doc Extensible_Storage_Engine_*
%doc Forensic_analysis_of_the_Windows_Search_database.pdf
%doc Windows_Search.pdf
%doc libesedb-libfdata.pdf
%_includedir/libesedb.h
%_includedir/libesedb/
%_libdir/libesedb.so
%_libdir/pkgconfig/libesedb.pc
%_mandir/man3/libesedb.3*

%files %python_files
%license COPYING*
%python_sitearch/pyesedb.so

%changelog
* Sat Apr 20 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240420
  * No changelog was provided
* Tue Feb  6 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240202
  * No user-visible changes
* Mon Nov 20 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20231120
  * Table lookup was reworked
  * Build system changes related to Python
* Tue Aug  1 2023 Greg Freemyer <Greg.Freemyer@gmail.com>
- use %%{?sle15_python_module_pythons} for opensuse15.5 compatibility
* Sat Mar 25 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20230318
  * Cyclic page detection
  * Improved format support
* Tue Jan  3 2023 Jan Engelhardt <jengelh@inai.de>
- Add missing Require on libbfio-devel.
* Sat Nov 26 2022 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (not needed - system libs are
  autodetected)
* Mon Aug 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update build requirement on libcfile
* Sat Aug  6 2022 Jan Engelhardt <jengelh@inai.de>
- Update to relase 20220806
  * Unspecified changes for error tollerance
* Fri Jan 21 2022 Jan Engelhardt <jengelh@inai.de>
- Edit specfile to do multipython builds.
  (Reenables python2 on Leap 15)
* Sat Jun 26 2021 Jan Engelhardt <jengelh@inai.de>
- Drop python2 module build.
* Fri May 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210513 (b0598ded)
  * No changelog was provided
- Add system-libs.patch
* Mon Dec 28 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20200418
  * worked on format support
  * changes to make esedbexport more tolerant for empty long values
  * worked on python bindings
* Sun Oct 11 2020 Christopher Yeleighton <giecrilj@stegny.2a.pl>
- add LGPL text
- add README to tools
* Tue May  5 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Allow distros to decide to no longer build python2 bindings
  (bcond_without python2). Tumbleweed declares this already.
* Tue Apr  7 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20191220
  * code clean-up
  * increased format support
- rename python-libesedb to python2-libesedb
- add python3 binding subpackage
- Use libcerror and libcstring from factory instead of internal versions
* Thu Mar 28 2019 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20181229
  * worked on Python 2 / 3 support
  * worked on Python bindings
  * multiple bug fixes
  * libfdata API change triggered changes
* Sun Feb  7 2016 Greg.Freemyer@gmail.com
- Use internal libcerror and libcstring to fix builds and segfault found in testing
* Fri Jan 29 2016 Greg.Freemyer@gmail.com
- update to v0~20151213
  * worked on support for newly discovered unknown page flag
  * removed LIBESEDB_FLAG_READ and LIBESEDB_FLAG_WRITE
  * worked on Python bindings
  * worked on setup.py
  * code clean up
- use libcerror, libcstring, libfdata packages from OBS again instead of internal versions
* Sat May 16 2015 Greg.Freemyer@gmail.com
- update to v0~20150409
  * 2015 update
  * changes for handling tagged data types in version 0x620 revision 0x14 database
  * changes for long value look up in dirty databases
  * changes for long value key compare
  * worked on long value support
  * worked on long value error tolerance
  * worked on NULL value support (JET_coltypNil)
  * worked on libfdata btree refactor
  * worked on Python 3 support
  * worked on Python bindings
  * worked on tests
  * code clean up
* Sun Jan 11 2015 Greg.Freemyer@gmail.com
- update to v0~20141110
- remove %%if opensuse logic.  Not needed now libyal is in security:forensics
- use libyal packages from OBS exclusively, nothing internal
- update URL to the new github site
- replace Source: field with fully defined URL
- remove DL-URL comment
* Fri Aug 22 2014 Greg.Freemyer@gmail.com
- initial package in OBS (v0~20140803)
